# ui.R - TAG Thermal Property Calculator
#
# Arun S. Moorthy, amoorthy@uoguelph.ca
# Alejandro G. Marangoni, amarango@uoguelph.ca
# University of Guelph
# ---------------------------------------------------------------------
rm(list=ls())
# Load Databases:
HEstimateParameters = read.csv("data/asmDB-SatAcidEnthalpyCoefficientEstimates.csv",header=TRUE)
TEstimateParameters = read.csv("data/asmDB-SatAcidTempCoefficientEstimates.csv",header=TRUE)
HEstimateParametersUNSAT = read.csv("data/asmDB-UnsatAcidEnthalpyCoefficientEstimates.csv",header=TRUE)
TEstimateParametersUNSAT = read.csv("data/asmDB-UnsatAcidTempCoefficientEstimates.csv",header=TRUE)
FattyAcids = read.csv("data/asmDB-FattyAcidsParameters.csv",header=TRUE)
ExperResults = read.csv("data/asmExperimentalThermalPropertyPureTAGDatabase.csv",header=TRUE)

HIJalpha = read.csv("data/GC-data/HIJ-alpha.csv",header=TRUE);
HIJbprime = read.csv("data/GC-data/HIJ-bprime.csv",header=TRUE);
HIJbeta = read.csv("data/GC-data/HIJ-beta.csv",header=TRUE);
KH = read.csv("data/GC-data/KH.csv",header=TRUE);

TIJalpha = read.csv("data/GC-data/TIJ-alpha.csv",header=TRUE);
TIJbprime = read.csv("data/GC-data/TIJ-bprime.csv",header=TRUE);
TIJbeta = read.csv("data/GC-data/TIJ-beta.csv",header=TRUE);
KT = read.csv("data/GC-data/KT.csv",header=TRUE);

options = as.character(FattyAcids$Name);
Polymorphs = c("alpha","beta prime", "beta");

shinyUI(fluidPage(
  theme="bootstrap.css",
  titlePanel("Triglyceride Property Calculator"),
  
 
  
  sidebarLayout(
    sidebarPanel(
      helpText("A melting property generator for pure triacylglycerides. To contribute experimental data, please contact one of the contributors."),
      selectInput("comp1", 
                  label = "sn1",
                  choices = options,
                  selected = options[17]),
      
      selectInput("comp2", 
                  label = "sn2",
                  choices = options,
                  selected = options[17]),
      
      selectInput("comp3", 
                  label = "sn3",
                  choices = options,
                  selected = options[17]),
      
      selectInput("polym", 
                  label = "Polymorphism",
                  choices = Polymorphs,
                  selected = Polymorphs[3]),
      
     p("(c) 2017",a("Marangoni Research Lab", href="http://www.crcfoodandhealth.com/",target="_blank"), "at the University of Guelph."),
     br(),
     div(strong("Contributors:"),br(),
        "Arun S. Moorthy (University of Guelph)",br(), 
        "Gianfranco Mazzantti (Dalhousie University)",br(),
        "Alejandro G. Marangoni (University of Guelph)",br(),br(),
        
         strong("References:"),br(),br(),
         tags$u("About Wesdorp Method:"),br(),
         "Moorthy, A.S. et al. Estimating thermodynamic properties of pure tryglyceride systems using the Triglyceride Property Calculator. (2017). 
         Journal of the American Oil Chemists' Society, 94(2), 187-199.",em("... and references therein"),a(" [MATHEMATICS SUMMARY]", href="http://www.crcfoodandhealth.com/downloads/asmTPC-webMathe.pdf",target="_blank"),
         br(),
         br(),
         tags$u("About Group Contribution (GC) Method:"),br(),
         "Zeberg-Mikkelsen. et al. Predicting the melting points and enthalpies of fusion of saturated triglycerides by a group contribution method. (1999).
         Fluid Phase Equilibria, 162(1), 7-17.",
    style = "color:black;font-size:8pt")
     
     ),

    mainPanel(
      p("Summary of triglyceride physical and melting properties",style = "color:black; font-size=12pt"),
      div(p(style="border: 5px solid blue"),
          
          tableOutput("Results"), 
          tags$style(type="text/css", "#Results table td {background-color:#FFFFFF;border-style: none}")),
      br(),
      
      div(tableOutput("Results2"), 
          tags$style(type="text/css", "#Results table td {background-color:#C2DFFF;border-style: none}"),    
          br(),
          p("Prediction [a] generated using combined temperature and enthalpy data. Prediction [b] generated using only temperature data. Both model fits described in linked summary document."),
      style="color:blue;font-size:12pt"),
      
      p(style="border: 5px solid blue"),
      
      div(p("DISCLAIMER: The Triglyceride Property Calculator (TPC) and underlying experimental data collection is a continual project. The authors of the TPC cannot
guarantee the accuracy of results generated using the TPC, and cannot validate
            claims of others based on results generated using the TPC. We encourage users to communicate known issues
            with the calculator and validate their findings with additional simulation and experiments."), 
      style = "color:black;font-size:12pt")
    )
  )
))
